@@ -1,5 +1,10 @@
 from __future__ import unicode_literals
 import re
+import string
+import sys
+
+
+PY3 = sys.version_info[0] == 3
 
 
 class StringProcessor(object):
@@ -9,33 +14,21 @@ class StringProcessor(object):
     for both input and output.
     """
 
+    regex = re.compile(r"(?ui)\W")
+
     @classmethod
     def replace_non_letters_non_numbers_with_whitespace(cls, a_string):
         """
         This function replaces any sequence of non letters and non
         numbers with a single white space.
         """
-        regex = re.compile(r"(?ui)\W")
-        return regex.sub(" ", a_string)
+        return cls.regex.sub(u" ", a_string)
 
-    @classmethod
-    def strip(cls, a_string):
-        """
-        This function strips leading and trailing white space.
-        """
-
-        return a_string.strip()
-
-    @classmethod
-    def to_lower_case(cls, a_string):
-        """
-        This function returns the lower-cased version of the string given.
-        """
-        return a_string.lower()
-
-    @classmethod
-    def to_upper_case(cls, a_string):
-        """
-        This function returns the upper-cased version of the string given.
-        """
-        return a_string.upper()
+    if PY3:
+        strip = staticmethod(str.strip)
+        to_lower_case = staticmethod(str.lower)
+        to_upper_case = staticmethod(str.upper)
+    else:
+        strip = staticmethod(string.strip)
+        to_lower_case = staticmethod(string.lower)
+        to_upper_case = staticmethod(string.upper)
