@@ -27,7 +27,7 @@ class StringProcessingTest(unittest.TestCase):
             proc_string = StringProcessor.replace_non_letters_non_numbers_with_whitespace(string)
             regex = re.compile(r"(?ui)[\W]")
             for expr in regex.finditer(proc_string):
-                self.assertEquals(expr.group(), " ")
+                self.assertEqual(expr.group(), " ")
 
     def test_dont_condense_whitespace(self):
         s1 = "new york mets - atlanta braves"
@@ -77,7 +77,6 @@ class UtilsTest(unittest.TestCase):
         for s in self.mixed_strings:
             utils.full_process(s, force_ascii=True)
 
-
 class RatioTest(unittest.TestCase):
 
     def setUp(self):
@@ -422,6 +421,51 @@ class ProcessTest(unittest.TestCase):
         best = process.extractOne(query, choices)
         self.assertEqual(best[0], choices[1])
 
+    def test_list_like_extract(self):
+        """We should be able to use a list-like object for choices."""
+        def generate_choices():
+            choices = ['a', 'Bb', 'CcC']
+            for choice in choices:
+                yield choice
+        search = 'aaa'
+        result = [(value, confidence) for value, confidence in
+                  process.extract(search, generate_choices())]
+        self.assertTrue(len(result) > 0)
+
+    def test_dict_like_extract(self):
+        """We should be able to use a dict-like object for choices, not only a
+        dict, and still get dict-like output.
+        """
+        try:
+            from UserDict import UserDict
+        except ImportError:
+            from collections import UserDict
+        choices = UserDict({'aa': 'bb', 'a1': None})
+        search = 'aaa'
+        result = process.extract(search, choices)
+        self.assertTrue(len(result) > 0)
+        for value, confidence, key in result:
+            self.assertTrue(value in choices.values())
+
+    def test_dedupe(self):
+        """We should be able to use a list-like object for contains_dupes
+        """
+        ## Test 1
+        contains_dupes = ['Frodo Baggins', 'Tom Sawyer', 'Bilbo Baggin', 'Samuel L. Jackson', 'F. Baggins', 'Frody Baggins', 'Bilbo Baggins']
+
+        result = process.dedupe(contains_dupes)
+        self.assertTrue(len(result) < len(contains_dupes))
+
+
+        ## Test 2
+        contains_dupes = ['Tom', 'Dick', 'Harry']
+        
+        # we should end up with the same list since no duplicates are contained in the list (e.g. original list is returned)
+        deduped_list = ['Tom','Dick','Harry']
+
+        result = process.dedupe(contains_dupes)
+        self.assertEqual(result, deduped_list)
+
 
 if __name__ == '__main__':
     unittest.main()         # run all tests
